package com.ruoyi.system.service;

import java.util.List;
import com.ruoyi.system.domain.QuoteType;

/**
 * 项目报价--工艺分类Service接口
 * 
 * @author ruoyi
 * @date 2025-05-14
 */
public interface IQuoteTypeService 
{
    /**
     * 查询项目报价--工艺分类
     * 
     * @param id 项目报价--工艺分类主键
     * @return 项目报价--工艺分类
     */
    public QuoteType selectQuoteTypeById(Long id);

    /**
     * 查询项目报价--工艺分类列表
     * 
     * @param quoteType 项目报价--工艺分类
     * @return 项目报价--工艺分类集合
     */
    public List<QuoteType> selectQuoteTypeList(QuoteType quoteType);

    /**
     * 新增项目报价--工艺分类
     * 
     * @param quoteType 项目报价--工艺分类
     * @return 结果
     */
    public int insertQuoteType(QuoteType quoteType);

    /**
     * 修改项目报价--工艺分类
     * 
     * @param quoteType 项目报价--工艺分类
     * @return 结果
     */
    public int updateQuoteType(QuoteType quoteType);

    /**
     * 批量删除项目报价--工艺分类
     * 
     * @param ids 需要删除的项目报价--工艺分类主键集合
     * @return 结果
     */
    public int deleteQuoteTypeByIds(Long[] ids);

    /**
     * 删除项目报价--工艺分类信息
     * 
     * @param id 项目报价--工艺分类主键
     * @return 结果
     */
    public int deleteQuoteTypeById(Long id);
}
